package org.jeecg.modules.api.travelController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.apiService.IndexApiService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;


@Api(tags="小程序-首页相关接口")
@RestController
@RequestMapping("/api/info")
@Slf4j
public class IndexApiController {

    @Resource
    private IndexApiService indexApiService;

    //获取小程序任一文章或服务

    //获取banner图列表
    @ApiOperation(value="小程序-获取banner图列表", notes="小程序-获取banner图列表")
    @GetMapping()
    @RequestMapping(value = "/queryBannerList", method = {RequestMethod.GET})
    public Result<?> queryBannerList(String bannerCategoryId){
        return indexApiService.queryBannerList(bannerCategoryId);
    };

    //获取视频列表
    @ApiOperation(value="小程序-获取视频列表", notes="小程序-获取视频列表")
    @RequestMapping(value = "/queryVideoList", method = {RequestMethod.GET})
    public Result<?> queryVideoList(){
        return indexApiService.queryVideoList();
    }

    //获取文章列表-申遗历程/非遗体验
    @ApiOperation(value="小程序-获取文章列表", notes="小程序-获取文章列表")
    @RequestMapping(value = "/queryArticleList", method = {RequestMethod.GET})
    public Result<?> queryArticleList(){
        return indexApiService.queryArticleList();
    }

    //根据分类获取文章列表
    @ApiOperation(value="小程序-根据分类获取文章列表", notes="小程序-根据分类获取文章列表")
    @RequestMapping(value = "/queryArticleListByType", method = {RequestMethod.GET})
    public Result<?> queryArticleListByType(String articleType){
        return indexApiService.queryArticleListByType(articleType);
    }

    //根据id获取文章详情
    @ApiOperation(value="小程序-根据id获取文章详情", notes="小程序-根据id获取文章详情")
    @RequestMapping(value = "/queryArticleById", method = {RequestMethod.GET})
    public Result<?> queryArticleById(String articleId){
        return indexApiService.queryArticleById(articleId);
    }

    //获取景区列表
    @ApiOperation(value="小程序-获取景区列表", notes="小程序-获取景区列表")
    @RequestMapping(value = "/queryAreaList", method = {RequestMethod.GET})
    public Result<?> queryAreaList(){
        return indexApiService.queryAreaList();
    }

    //根据景区id获取该景区下的地点列表-景点/厕所/美食店铺/民宿
    @ApiOperation(value="小程序-根据景区id获取该景区下的地点列表:景点/厕所/美食店铺/民宿", notes="小程序-根据景区id获取该景区下的地点列表:景点/厕所/美食店铺/民宿")
    @RequestMapping(value = "/querySpotList", method = {RequestMethod.GET})
    public Result<?> querySpotList(String areaId, String categoryId){
        return indexApiService.querySpotList(areaId, categoryId);
    }

    //根据角色类型获取角色信息列表-讲解员/达人/摄影师
    @ApiOperation(value="小程序-根据角色类型获取角色信息列表-讲解员/达人/摄影师", notes="1-讲解员，2-达人，3-摄影师")
    @RequestMapping(value = "/queryRoleInfoList", method = {RequestMethod.GET})
    public Result<?> queryRoleInfoList(String roleType, String level, String spot){
        return indexApiService.queryRoleInfoList(roleType, level, spot);
    }

    //根据角色id获取角色信息详情
    @ApiOperation(value="小程序-根据角色类型获取角色信息列表", notes="小程序-根据角色类型获取角色信息列表")
    @RequestMapping(value = "/queryRoleInfoById", method = {RequestMethod.GET})
    public Result<?> queryRoleInfoById(String roleInfoId){
        return indexApiService.queryRoleInfoById(roleInfoId);
    }

    //根据角色id获取视频列表
    @ApiOperation(value="小程序-根据角色id获取视频列表", notes="小程序-根据角色id获取视频列表")
    @RequestMapping(value = "/queryVedioBySpot", method = {RequestMethod.GET})
    public Result<?> queryVedioById(String roleInfoId){
        return indexApiService.queryVedioById(roleInfoId);
    }

    //遗产路径-待补充

    //我要研学-待补充

    //文创好物-待补充

    //瓷都美食-链接美团

    //精品民宿-链接高德地图

    //无忧租车-链接滴滴打车

    //添加建议
    @ApiOperation(value="小程序-添加建议", notes="小程序-添加建议")
    @RequestMapping(value = "/addAdvice", method = {RequestMethod.POST})
    public Result<?> addAdvice(){
        return indexApiService.addAdvice();
    }

    /*************************我的***********************************/
    //添加志愿者
    @ApiOperation(value="小程序-添加支援者", notes="小程序-添加支援者")
    @RequestMapping(value = "/addVolunteer", method = {RequestMethod.POST})
    public Result<?> addVolunteer(){
        return indexApiService.addVolunteer();
    }


}
