package org.jeecg.modules.apiService.impl;

import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.apiService.IndexApiService;
import org.jeecg.modules.hanHaiMember.service.IHanHaiMemberService;
import org.jeecg.modules.travelArea.entity.TravelArea;
import org.jeecg.modules.travelArea.service.ITravelAreaService;
import org.jeecg.modules.travelArticle.entity.TravelArticle;
import org.jeecg.modules.travelArticle.service.ITravelArticleService;
import org.jeecg.modules.travelCategory.service.ITravelCategoryService;
import org.jeecg.modules.travelCertification.service.ITravelCertificationService;
import org.jeecg.modules.travelImage.entity.TravelImage;
import org.jeecg.modules.travelImage.service.ITravelImageService;
import org.jeecg.modules.travelOrder.service.ITravelOrderService;
import org.jeecg.modules.travelRole.service.ITravelRoleService;
import org.jeecg.modules.travelRoleInfo.entity.TravelRoleInfo;
import org.jeecg.modules.travelRoleInfo.service.ITravelRoleInfoService;
import org.jeecg.modules.travelSpot.entity.TravelSpot;
import org.jeecg.modules.travelSpot.service.ITravelSpotService;
import org.jeecg.modules.travelVideo.entity.TravelVideo;
import org.jeecg.modules.travelVideo.service.ITravelVideoService;
import org.jeecg.modules.travelVolunteer.service.ITravelVolunteerService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

@Service
public class IndexApiServiceImpl implements IndexApiService {

    //获取小程序任一文章或服务

    //用户表
    @Resource
    private IHanHaiMemberService hanHaiMemberService;
    //角色表
    @Resource
    private ITravelRoleService travelRoleService;
    //角色信息表
    @Resource
    private ITravelRoleInfoService travelRoleInfoService;
    //景区表
    @Resource
    private ITravelAreaService travelAreaService;
    //景点表
    @Resource
    private ITravelSpotService travelSpotService;
    //分类表
    @Resource
    private ITravelCategoryService travelCategoryService;
    //图片表
    @Resource
    private ITravelImageService travelImageService;
    //文章表
    @Resource
    private ITravelArticleService travelArticleService;
    //视频表
    @Resource
    private ITravelVideoService travelVideoService;
    //证件表
    @Resource
    private ITravelCertificationService travelCertificationService;
    //订单表
    @Resource
    private ITravelOrderService travelOrderService;
    //志愿者表
    @Resource
    private ITravelVolunteerService travelVolunteerService;

    //获取轮播图列表
    @Override
    public Result<?> queryBannerList(String bannerCategoryId) {
        List<TravelImage> list = travelImageService
                .lambdaQuery()
                .eq(TravelImage::getCategoryId, bannerCategoryId)
                .list();

        return Result.OK("轮播图列表", list);
    }

    //获取视频列表
    @Override
    public Result<?> queryVideoList() {
        List<TravelVideo> list = travelVideoService.list();

        return Result.OK("视频列表", list);
    }

    //获取文章列表
    @Override
    public Result<?> queryArticleList() {
        List<TravelArticle> list = travelArticleService.list();

        return Result.OK("文章列表", list);
    }

    //根据文章类型获取文章列表
    @Override
    public Result<?> queryArticleListByType(String articleType) {
        List<TravelArticle> list = travelArticleService
                .lambdaQuery()
                .eq(TravelArticle::getCategoryId, articleType)
                .list();

        return Result.OK("文章列表", list);
    }

    //根据文章id获取文章详情
    @Override
    public Result<?> queryArticleById(String articleId) {
        TravelArticle one = travelArticleService
                .lambdaQuery()
                .eq(TravelArticle::getId, articleId)
                .one();

        return Result.OK("文章列表", one);
    }

    //获取景区列表
    @Override
    public Result<?> queryAreaList() {
        List<TravelArea> list = travelAreaService.list();

        return Result.OK("景区列表", list);
    }

    //根据景区id获取该景区下的地点列表-景点/厕所/美食店铺/民宿
    @Override
    public Result<?> querySpotList(String areaId, String categoryId) {
        List<TravelSpot> list = travelSpotService
                .lambdaQuery()
                .eq(TravelSpot::getAreaId, areaId)
                .eq(TravelSpot::getCategoryId, categoryId)
                .list();

        return Result.OK("景点列表", list);
    }

    //根据角色类型获取角色信息列表
    @Override
    public Result<?> queryRoleInfoList(String roleType, String level, String spot) {
        List<TravelRoleInfo> list = travelRoleInfoService
                .lambdaQuery()
                .eq(TravelRoleInfo::getRoleId, roleType)
                .eq(TravelRoleInfo::getRoleLevel, level)
                .like(TravelRoleInfo::getSkill, spot)
                .list();

        return Result.OK("景点列表", list);
    }

    //根据角色id获取角色详情
    @Override
    public Result<?> queryRoleInfoById(String roleInfoId) {
        TravelRoleInfo one = travelRoleInfoService
                .lambdaQuery()
                .eq(TravelRoleInfo::getId, roleInfoId)
                .one();

        return Result.OK("角色详情", one);
    }

    //根据视频创建者获取视频列表
    @Override
    public Result<?> queryVedioById(String roleInfoId) {
        List<TravelVideo> list = travelVideoService
                .lambdaQuery()
                .eq(TravelVideo::getCreateBy, roleInfoId)
                .list();

        return Result.OK("视频列表", list);
    }

    //添加建议
    @Override
    public Result<?> addAdvice() {
        return null;
    }

    //添加志愿者
    @Override
    public Result<?> addVolunteer() {
        return null;
    }
}
